==> kolibri-0.17.4.tar.gz: kolibri-0.17.4/README.md <==

# Kolibri

[![Python test status](https://github.com/learningequality/kolibri/actions/workflows/tox.yml/badge.svg?branch=develop)](https://github.com/learningequality/kolibri/actions/workflows/tox.yml)
[![JS test status](https://github.com/learningequality/kolibri/actions/workflows/yarn.yml/badge.svg?branch=develop)](https://github.com/learningequality/kolibri/actions/workflows/yarn.yml)
[![Developer docs](https://img.shields.io/badge/docs-dev-blue.svg)](http://kolibri-dev.readthedocs.org/en/develop/)
[![Developer chat](https://img.shields.io/badge/chat-dev-blue.svg)](http://webchat.freenode.net?channels=%23kolibri)
[![PyPI](https://img.shields.io/pypi/v/kolibri.svg?color=blue)](https://pypi.org/project/kolibri/)
[![Demo](https://img.shields.io/badge/demo-online-blue.svg)](http://kolibridemo.learningequality.org/)
[![User docs](https://img.shields.io/badge/docs-user-blue.svg)](http://kolibri.readthedocs.org/en/latest/)
[![Discourse topics](https://img.shields.io/discourse/https/community.learningequality.org/topics.svg?color=blue)](https://community.learningequality.org/)

This repository is for software developers wishing to contribute to Kolibri. If you are looking for help installing, configuring and using Kolibri, please refer to the [User Guide](https://kolibri.readthedocs.io/).


## What is Kolibri?

[Kolibri Learning Platform](https://learningequality.org/kolibri/): the offline-first platform for teaching and learning with technology without requiring the Internet.

Developed with and for the community by [Learning Equality](https://learningequality.org/).

## How can I use it?

Kolibri is [available for download](https://learningequality.org/download/) from our website.

## How do I get help or give feedback?

You can ask questions, make suggestions, and report issues in the [community forums](https://community.learningequality.org/).

If you have found a bug and are comfortable using Github and Markdown, you can create a [Github issue](https://github.com/learningequality/kolibri/issues) following the instructions in the issue template.

<!-- Also update CONTRIBUTING.md (duplicate) -->
## How can I contribute?

1. 📙 **Skim through the [Developer documentation](https://kolibri-dev.readthedocs.io)** to understand where to refer later on.
2. 💻 **Follow the [Getting started](https://kolibri-dev.readthedocs.io/en/develop/getting_started.html) to set up your development server.** Some of the [How To Guides](https://kolibri-dev.readthedocs.io/en/develop/howtos/index.html#howtos) may be handy too.
3. 🔍 **Search for issues tagged as [help wanted](https://github.com/learningequality/kolibri/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22+no%3Aassignee) or [good first issue](https://github.com/learningequality/kolibri/issues?q=is%3Aissue+is%3Aopen+label%3A%22good+first+issue%22+no%3Aassignee).**
4. 🗣️ **Ask us for an assignment in the comments of an issue you've chosen.** Please request assignment of a reasonable amount of issues at a time. Once you finish your current issue or two, you are welcome to ask for more.

**❓ Where to ask questions**

- For anything development related, refer to the [Developer documentation](https://kolibri-dev.readthedocs.io) at first. Some answers may already be there.
- For questions related to a specific issue or assignment requests, use the corresponding issue's comments section.
- Visit [GitHub Discussions](https://github.com/learningequality/kolibri/discussions) to ask about anything related to contributing or to troubleshoot development server issues.

**👥 How to connect**

- We encourage you to visit [GitHub Discussions](https://github.com/learningequality/kolibri/discussions) to connect with the Learning Equality team as well as with other contributors.
- If you'd like to contribute on a regular basis, we are happy to invite you to our open-source community Slack channel. Get in touch with us at info@learningequality.org to receive an invitation.

---

🕖 Please allow us a few days to reply to your comments. If you don't hear from us within a week, reach out via [GitHub Discussions](https://github.com/learningequality/kolibri/discussions).

As soon as you open a pull request, it may take us a week or two to review it as we're a small team. We appreciate your contribution and will provide feedback.

---

*Thank you for your interest in contributing! Learning Equality was founded by volunteers dedicated to helping make educational materials more accessible to those in need, and every contribution makes a difference.*

==> kolibri-0.18.0.tar.gz: kolibri-0.18.0/README.md <==

# Kolibri

[![Python test status](https://github.com/learningequality/kolibri/actions/workflows/tox.yml/badge.svg?branch=develop)](https://github.com/learningequality/kolibri/actions/workflows/tox.yml)
[![JS test status](https://github.com/learningequality/kolibri/actions/workflows/yarn.yml/badge.svg?branch=develop)](https://github.com/learningequality/kolibri/actions/workflows/yarn.yml)
[![Developer docs](https://img.shields.io/badge/docs-dev-blue.svg)](http://kolibri-dev.readthedocs.org/en/develop/)
[![Developer chat](https://img.shields.io/badge/chat-dev-blue.svg)](http://webchat.freenode.net?channels=%23kolibri)
[![PyPI](https://img.shields.io/pypi/v/kolibri.svg?color=blue)](https://pypi.org/project/kolibri/)
[![Demo](https://img.shields.io/badge/demo-online-blue.svg)](http://kolibridemo.learningequality.org/)
[![User docs](https://img.shields.io/badge/docs-user-blue.svg)](http://kolibri.readthedocs.org/en/latest/)
[![Discourse topics](https://img.shields.io/discourse/https/community.learningequality.org/topics.svg?color=blue)](https://community.learningequality.org/)

This repository is for software developers wishing to contribute to Kolibri. If you are looking for help installing, configuring and using Kolibri, please refer to the [User Guide](https://kolibri.readthedocs.io/).


## What is Kolibri?

[Kolibri Learning Platform](https://learningequality.org/kolibri/): the offline-first platform for teaching and learning with technology without requiring the Internet.

Developed with and for the community by [Learning Equality](https://learningequality.org/).

## How can I use it?

Kolibri is [available for download](https://learningequality.org/download/) from our website.

## How do I get help or give feedback?

You can ask questions, make suggestions, and report issues in the [community forums](https://community.learningequality.org/).

If you have found a bug and are comfortable using Github and Markdown, you can create a [Github issue](https://github.com/learningequality/kolibri/issues) following the instructions in the issue template.

<!-- Also update CONTRIBUTING.md (duplicate) -->
## How can I contribute?

1. 📙 **Skim through the [Developer documentation](https://kolibri-dev.readthedocs.io)** to understand where to refer later on.
2. 💻 **Follow the [Getting started](https://kolibri-dev.readthedocs.io/en/develop/getting_started.html) to set up your development server.** Some of the [How To Guides](https://kolibri-dev.readthedocs.io/en/develop/howtos/index.html#howtos) may be handy too.
3. 🔍 **Search for issues tagged as [help wanted](https://github.com/learningequality/kolibri/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22+no%3Aassignee) or [good first issue](https://github.com/learningequality/kolibri/issues?q=is%3Aissue+is%3Aopen+label%3A%22good+first+issue%22+no%3Aassignee).**
4. 🗣️ **Ask us for an assignment in the comments of an issue you've chosen.** Please request assignment of a reasonable amount of issues at a time. Once you finish your current issue or two, you are welcome to ask for more.

**❓ Where to ask questions**

- For anything development related, refer to the [Developer documentation](https://kolibri-dev.readthedocs.io) at first. Some answers may already be there.
- For questions related to a specific issue or assignment requests, use the corresponding issue's comments section.
- Visit [GitHub Discussions](https://github.com/learningequality/kolibri/discussions) to ask about anything related to contributing or to troubleshoot development server issues.

**👥 How to connect**

- We encourage you to visit [GitHub Discussions](https://github.com/learningequality/kolibri/discussions) to connect with the Learning Equality team as well as with other contributors.
- To get access to the GSOC 2025 Slack channel, send us an e-mail at gsoc@learningequality.org.
- If you'd like to contribute on a regular basis, we are happy to invite you to our open-source community Slack channel. Get in touch with us at contributors@learningequality.org to receive an invitation.

---

🕖 Please allow us a few days to reply to your comments. If you don't hear from us within a week, reach out via [GitHub Discussions](https://github.com/learningequality/kolibri/discussions).

As soon as you open a pull request, it may take us a week or two to review it as we're a small team. We appreciate your contribution and will provide feedback.

---

*Thank you for your interest in contributing! Learning Equality was founded by volunteers dedicated to helping make educational materials more accessible to those in need, and every contribution makes a difference.*
